@@ -156,7 +156,10 @@ class GrpcToRest:
         return rest.HnswConfigDiff(
             ef_construct=model.ef_construct if model.HasField("ef_construct") else None,
             m=model.m if model.HasField("m") else None,
-            full_scan_threshold=model.full_scan_threshold if model.HasField("full_scan_threshold") else None
+            full_scan_threshold=model.full_scan_threshold if model.HasField("full_scan_threshold") else None,
+            max_indexing_threads=model.max_indexing_threads if model.HasField("max_indexing_threads") else None,
+            on_disk=model.on_disk if model.HasField("on_disk") else None,
+            payload_m=model.payload_m if model.HasField("payload_m") else None,
         )
 
     @classmethod
@@ -164,7 +167,10 @@ class GrpcToRest:
         return rest.HnswConfig(
             ef_construct=model.ef_construct if model.HasField("ef_construct") else None,
             m=model.m if model.HasField("m") else None,
-            full_scan_threshold=model.full_scan_threshold if model.HasField("full_scan_threshold") else None
+            full_scan_threshold=model.full_scan_threshold if model.HasField("full_scan_threshold") else None,
+            max_indexing_threads=model.max_indexing_threads if model.HasField("max_indexing_threads") else None,
+            on_disk=model.on_disk if model.HasField("on_disk") else None,
+            payload_m=model.payload_m if model.HasField("payload_m") else None,
         )
 
     @classmethod
@@ -585,6 +591,7 @@ class GrpcToRest:
             with_vector=cls.convert_with_vectors_selector(
                 model.with_vectors) if model.HasField("with_vectors") else None,
             using=model.using,
+            lookup_from=cls.convert_lookup_location(model.lookup_from) if model.HasField("lookup_from") else None,
         )
 
     @classmethod
@@ -615,6 +622,13 @@ class GrpcToRest:
                 "write_consistency_factor") else None,
         )
 
+    @classmethod
+    def convert_lookup_location(cls, model: grpc.LookupLocation) -> rest.LookupLocation:
+        return rest.LookupLocation(
+            collection=model.collection_name,
+            vector=model.vector_name if model.HasField("vector_name") else None,
+        )
+
 
 # ----------------------------------------
 #
@@ -829,6 +843,9 @@ class RestToGrpc:
             ef_construct=model.ef_construct,
             full_scan_threshold=model.full_scan_threshold,
             m=model.m,
+            max_indexing_threads=model.max_indexing_threads,
+            on_disk=model.on_disk,
+            payload_m=model.payload_m,
         )
 
     @classmethod
@@ -882,6 +899,9 @@ class RestToGrpc:
             ef_construct=model.ef_construct,
             full_scan_threshold=model.full_scan_threshold,
             m=model.m,
+            max_indexing_threads=model.max_indexing_threads,
+            on_disk=model.on_disk,
+            payload_m=model.payload_m,
         )
 
     @classmethod
@@ -1173,6 +1193,7 @@ class RestToGrpc:
             offset=model.offset,
             with_vectors=cls.convert_with_vectors(model.with_vector) if model.with_vector is not None else None,
             using=model.using,
+            lookup_from=cls.convert_lookup_location(model.lookup_from) if model.lookup_from is not None else None,
         )
 
     @classmethod
@@ -1205,3 +1226,10 @@ class RestToGrpc:
             replication_factor=model.replication_factor,
             write_consistency_factor=model.write_consistency_factor,
         )
+
+    @classmethod
+    def convert_lookup_location(cls, model: rest.LookupLocation) -> grpc.LookupLocation:
+        return grpc.LookupLocation(
+            collection_name=model.collection,
+            vector_name=model.vector,
+        )
