@@ -251,6 +251,28 @@ class _SnapshotsApi:
             path_params=path_params,
         )
 
+    def _build_for_recover_from_snapshot(
+        self,
+        collection_name: str,
+        snapshot_recover: m.SnapshotRecover = None,
+    ):
+        """
+        Recover local collection data from a snapshot. This will overwrite any data, stored on this node, for the collection.
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+        }
+
+        body = jsonable_encoder(snapshot_recover)
+
+        return self.api_client.request(
+            type_=m.InlineResponse2003,
+            method="PUT",
+            url="/collections/{collection_name}/snapshots/recover",
+            path_params=path_params,
+            json=body,
+        )
+
 
 class AsyncSnapshotsApi(_SnapshotsApi):
     async def create_full_snapshot(
@@ -315,6 +337,19 @@ class AsyncSnapshotsApi(_SnapshotsApi):
             collection_name=collection_name,
         )
 
+    async def recover_from_snapshot(
+        self,
+        collection_name: str,
+        snapshot_recover: m.SnapshotRecover = None,
+    ) -> m.InlineResponse2003:
+        """
+        Recover local collection data from a snapshot. This will overwrite any data, stored on this node, for the collection.
+        """
+        return await self._build_for_recover_from_snapshot(
+            collection_name=collection_name,
+            snapshot_recover=snapshot_recover,
+        )
+
 
 class SyncSnapshotsApi(_SnapshotsApi):
     def create_full_snapshot(
@@ -378,3 +413,16 @@ class SyncSnapshotsApi(_SnapshotsApi):
         return self._build_for_list_snapshots(
             collection_name=collection_name,
         )
+
+    def recover_from_snapshot(
+        self,
+        collection_name: str,
+        snapshot_recover: m.SnapshotRecover = None,
+    ) -> m.InlineResponse2003:
+        """
+        Recover local collection data from a snapshot. This will overwrite any data, stored on this node, for the collection.
+        """
+        return self._build_for_recover_from_snapshot(
+            collection_name=collection_name,
+            snapshot_recover=snapshot_recover,
+        )
