@@ -82,6 +82,8 @@ class ClusterStatusTelemetry(BaseModel):
     pending_operations: int = Field(..., description="")
     role: Optional["StateRole"] = Field(None, description="")
     is_voter: bool = Field(..., description="")
+    peer_id: Optional[int] = Field(None, description="")
+    consensus_thread_status: "ConsensusThreadStatus" = Field(..., description="")
 
 
 class ClusterTelemetry(BaseModel):
@@ -172,6 +174,7 @@ class CollectionTelemetry(BaseModel):
     init_time_ms: int = Field(..., description="")
     config: "CollectionConfig" = Field(..., description="")
     shards: List["ReplicaSetTelemetry"] = Field(..., description="")
+    transfers: List["ShardTransferInfo"] = Field(..., description="")
 
 
 class CollectionsAggregatedTelemetry(BaseModel):
@@ -304,8 +307,11 @@ class DeleteAliasOperation(BaseModel):
 
 
 class DeletePayload(BaseModel):
-    keys: List[str] = Field(..., description="")
-    points: List["ExtendedPointId"] = Field(..., description="Deletes values from each point in this list")
+    keys: List[str] = Field(..., description="List of payload keys to remove from payload")
+    points: Optional[List["ExtendedPointId"]] = Field(None, description="Deletes values from each point in this list")
+    filter: Optional["Filter"] = Field(
+        None, description="Deletes values from points that satisfy this filter condition"
+    )
 
 
 class Distance(str, Enum):
@@ -421,6 +427,12 @@ class HnswConfig(BaseModel):
     max_indexing_threads: Optional[int] = Field(
         0, description="Number of parallel threads used for background index building. If 0 - auto selection."
     )
+    on_disk: Optional[bool] = Field(
+        None, description="Store HNSW index on disk. If set to false, index will be stored in RAM. Default: false"
+    )
+    payload_m: Optional[int] = Field(
+        None, description="Custom M param for hnsw graph built for payload index. If not set, default M will be used."
+    )
 
 
 class HnswConfigDiff(BaseModel):
@@ -436,6 +448,15 @@ class HnswConfigDiff(BaseModel):
         None,
         description="Minimal size (in KiloBytes) of vectors for additional payload-based indexing. If payload chunk is smaller than `full_scan_threshold_kb` additional indexing won&#x27;t be used - in this case full-scan search should be preferred by query planner and additional indexing is not required. Note: 1Kb = 1 vector of size 256",
     )
+    max_indexing_threads: Optional[int] = Field(
+        None, description="Number of parallel threads used for background index building. If 0 - auto selection."
+    )
+    on_disk: Optional[bool] = Field(
+        None, description="Store HNSW index on disk. If set to false, index will be stored in RAM. Default: false"
+    )
+    payload_m: Optional[int] = Field(
+        None, description="Custom M param for additional payload-aware HNSW links. If not set, default M will be used."
+    )
 
 
 class IndexesOneOf(BaseModel):
@@ -621,6 +642,18 @@ class LocksOption(BaseModel):
     write: bool = Field(..., description="")
 
 
+class LookupLocation(BaseModel):
+    """
+    Defines a location to use for looking up the vector. Specifies collection and vector field name.
+    """
+
+    collection: str = Field(..., description="Name of the collection used for lookup")
+    vector: Optional[str] = Field(
+        None,
+        description="Optional name of the vector field within the collection. If not provided, the default vector field will be used.",
+    )
+
+
 class MatchText(BaseModel):
     """
     Full-text match of the strings.
@@ -876,7 +909,7 @@ class RecommendRequest(BaseModel):
     """
 
     positive: List["ExtendedPointId"] = Field(..., description="Look for vectors closest to those")
-    negative: List["ExtendedPointId"] = Field(..., description="Try to avoid vectors like this")
+    negative: Optional[List["ExtendedPointId"]] = Field([], description="Try to avoid vectors like this")
     filter: Optional["Filter"] = Field(None, description="Look only for points which satisfies this conditions")
     params: Optional["SearchParams"] = Field(None, description="Additional search params")
     limit: int = Field(..., description="Max number of result to return")
@@ -895,6 +928,10 @@ class RecommendRequest(BaseModel):
     using: Optional["UsingVector"] = Field(
         None, description="Define which vector to use for recommendation, if not specified - try to use default vector"
     )
+    lookup_from: Optional["LookupLocation"] = Field(
+        None,
+        description="The location used to lookup vectors. If not specified - use current collection. Note: the other collection should have the same vector size as the current collection",
+    )
 
 
 class RecommendRequestBatch(BaseModel):
@@ -919,6 +956,7 @@ class RemoteShardInfo(BaseModel):
 
 class RemoteShardTelemetry(BaseModel):
     shard_id: int = Field(..., description="")
+    peer_id: Optional[int] = Field(None, description="")
     searches: "OperationDurationStatistics" = Field(..., description="")
     updates: "OperationDurationStatistics" = Field(..., description="")
 
@@ -949,6 +987,7 @@ class ReplicaSetTelemetry(BaseModel):
     id: int = Field(..., description="")
     local: Optional["LocalShardTelemetry"] = Field(None, description="")
     remote: List["RemoteShardTelemetry"] = Field(..., description="")
+    replicate_states: Dict[str, "ReplicaState"] = Field(..., description="")
 
 
 class ReplicaState(str, Enum):
@@ -1098,7 +1137,10 @@ class SegmentType(str, Enum):
 
 class SetPayload(BaseModel):
     payload: "Payload" = Field(..., description="")
-    points: List["ExtendedPointId"] = Field(..., description="Assigns payload to each point in this list")
+    points: Optional[List["ExtendedPointId"]] = Field(None, description="Assigns payload to each point in this list")
+    filter: Optional["Filter"] = Field(
+        None, description="Assigns payload to each point that satisfy this filter condition"
+    )
 
 
 class ShardTransferInfo(BaseModel):
@@ -1117,6 +1159,19 @@ class SnapshotDescription(BaseModel):
     size: int = Field(..., description="")
 
 
+class SnapshotPriority(str, Enum):
+    SNAPSHOT = "snapshot"
+    REPLICA = "replica"
+
+
+class SnapshotRecover(BaseModel):
+    location: str = Field(
+        ...,
+        description="Examples: - URL `http://localhost:8080/collections/my_collection/snapshots/my_snapshot` - Local path `file:///qdrant/snapshots/test_collection-2022-08-04-10-49-10.snapshot`",
+    )
+    priority: Optional["SnapshotPriority"] = Field(None, description="")
+
+
 class StateRole(str, Enum):
     FOLLOWER = "Follower"
     CANDIDATE = "Candidate"
