@@ -49,6 +49,13 @@ class QdrantClient:
         prefer_grpc: If `true` - use gPRC interface whenever possible in custom methods.
         https: If `true` - use HTTPS(SSL) protocol. Default: `false`
         api_key: API key for authentication in Qdrant Cloud. Default: `None`
+        prefix:
+            If not `None` - add `prefix` to the REST URL path.
+            Example: `service/v1` will result in `http://localhost:6333/service/v1/{qdrant-endpoint}` for REST API.
+            Default: `None`
+        timeout:
+            Timeout for REST and gRPC API requests.
+            Default: 5.0 seconds for REST and unlimited for gRPC
         **kwargs: Additional arguments passed directly into REST client initialization
     """
 
@@ -59,11 +66,18 @@ class QdrantClient:
                  prefer_grpc=False,
                  https=None,
                  api_key=None,
+                 prefix=None,
+                 timeout=None,
                  **kwargs):
         self._prefer_grpc = prefer_grpc
         self._grpc_port = grpc_port
         self._host = host
         self._port = port
+        self._prefix = prefix
+        self._timeout = timeout
+
+        if prefix is not None and len(prefix) > 0 and prefix[0] != '/':
+            self._prefix = f"/{prefix}"
 
         self._https = https
         self._api_key = api_key
@@ -89,7 +103,7 @@ class QdrantClient:
             self._rest_headers['api-key'] = api_key
             self._grpc_headers.append(('api-key', api_key))
 
-        self.rest_uri = f"http{'s' if self._https else ''}://{host}:{port}"
+        self.rest_uri = f"http{'s' if self._https else ''}://{host}:{port}{self._prefix if self._prefix is not None else ''}"
         self._rest_args = {
             "headers": self._rest_headers,
             "http2": http2,
@@ -99,6 +113,9 @@ class QdrantClient:
         if limits is not None:
             self._rest_args['limits'] = limits
 
+        if self._timeout is not None:
+            self._rest_args['timeout'] = self._timeout
+
         self.openapi_client = SyncApis(host=self.rest_uri, **self._rest_args)
 
         self._grpc_channel = None
@@ -181,7 +198,7 @@ class QdrantClient:
                 grpc.SearchBatchPoints(
                     collection_name=collection_name,
                     search_points=requests,
-                )
+                ), timeout=self._timeout
             )
 
             return [[GrpcToRest.convert_scored_point(hit) for hit in r.result] for r in res.result]
@@ -321,7 +338,7 @@ class QdrantClient:
                 with_payload=with_payload,
                 params=search_params,
                 score_threshold=score_threshold
-            ))
+            ), timeout=self._timeout)
 
             return [GrpcToRest.convert_scored_point(hit) for hit in res.result]
 
@@ -377,7 +394,8 @@ class QdrantClient:
                 grpc.RecommendBatchPoints(
                     collection_name=collection_name,
                     recommend_points=requests,
-                )
+                ),
+                timeout=self._timeout
             )
 
             return [[GrpcToRest.convert_scored_point(hit) for hit in r.result] for r in res.result]
@@ -405,6 +423,7 @@ class QdrantClient:
             with_vectors: Union[bool, List[str]] = False,
             score_threshold: Optional[float] = None,
             using: Optional[str] = None,
+            lookup_from: Optional[types.LookupLocation] = None,
             top: int = None,
     ) -> List[types.ScoredPoint]:
         """Recommend points: search for similar points based on already stored in Qdrant examples.
@@ -451,6 +470,9 @@ class QdrantClient:
             using:
                 Name of the vectors to use for recommendations.
                 If `None` - use default vectors.
+            lookup_from:
+                Defines a location (collection and vector field name), used to lookup vectors for recommendations.
+                If `None` - use current collection will be used.
             top: Same as `limit`. Deprecated.
 
         Returns:
@@ -495,6 +517,9 @@ class QdrantClient:
             )):
                 with_vectors = RestToGrpc.convert_with_vectors(with_vectors)
 
+            if isinstance(lookup_from, rest.LookupLocation):
+                lookup_from = RestToGrpc.convert_lookup_location(lookup_from)
+
             res: grpc.SearchResponse = self._grpc_points_client.Recommend(grpc.RecommendPoints(
                 collection_name=collection_name,
                 positive=positive,
@@ -506,8 +531,9 @@ class QdrantClient:
                 with_payload=with_payload,
                 params=search_params,
                 score_threshold=score_threshold,
-                using=using
-            ))
+                using=using,
+                lookup_from=lookup_from,
+            ), timeout=self._timeout)
 
             return [GrpcToRest.convert_scored_point(hit) for hit in res.result]
         else:
@@ -530,6 +556,9 @@ class QdrantClient:
             if isinstance(with_payload, grpc.WithPayloadSelector):
                 with_payload = GrpcToRest.convert_with_payload_selector(with_payload)
 
+            if isinstance(lookup_from, grpc.LookupLocation):
+                lookup_from = GrpcToRest.convert_lookup_location(lookup_from)
+
             return self.openapi_client.points_api.recommend_points(
                 collection_name=collection_name,
                 recommend_request=rest.RecommendRequest(
@@ -542,6 +571,7 @@ class QdrantClient:
                     with_payload=with_payload,
                     with_vector=with_vectors,
                     score_threshold=score_threshold,
+                    lookup_from=lookup_from,
                     using=using
                 )
             ).result
@@ -609,7 +639,7 @@ class QdrantClient:
                 with_vectors=with_vectors,
                 with_payload=with_payload,
                 limit=limit
-            ))
+            ), timeout=self._timeout)
 
             return [
                        GrpcToRest.convert_retrieved_point(point)
@@ -712,10 +742,10 @@ class QdrantClient:
                 ]
 
             return GrpcToRest.convert_update_result(self._grpc_points_client.Upsert(grpc.UpsertPoints(
-                    collection_name=collection_name,
-                    wait=wait,
-                    points=points
-                )).result)
+                collection_name=collection_name,
+                wait=wait,
+                points=points
+            ), timeout=self._timeout).result)
         else:
             if isinstance(points, list):
                 points = [
@@ -783,11 +813,11 @@ class QdrantClient:
                 with_vectors = RestToGrpc.convert_with_vectors(with_vectors)
 
             result = self._grpc_points_client.Get(grpc.GetPoints(
-                    collection_name=collection_name,
-                    ids=ids,
-                    with_payload=with_payload,
-                    with_vectors=with_vectors
-                )).result
+                collection_name=collection_name,
+                ids=ids,
+                with_payload=with_payload,
+                with_vectors=with_vectors
+            ), timeout=self._timeout).result
 
             return [
                 GrpcToRest.convert_retrieved_point(record)
@@ -812,6 +842,94 @@ class QdrantClient:
                 )
             ).result
 
+    @classmethod
+    def _try_argument_to_grpc_selector(
+            cls,
+            points: types.PointsSelector
+    ) -> grpc.PointsSelector:
+        if isinstance(points, list):
+            points_selector = grpc.PointsSelector(
+                points=grpc.PointsIdsList(ids=[
+                    RestToGrpc.convert_extended_point_id(idx) if isinstance(idx, (int, str)) else idx
+                    for idx in points
+                ]))
+        elif isinstance(points, grpc.PointsSelector):
+            points_selector = points
+        elif isinstance(points, (rest.PointIdsList, rest.FilterSelector)):
+            points_selector = RestToGrpc.convert_points_selector(points)
+        elif isinstance(points, rest.Filter):
+            points_selector = RestToGrpc.convert_points_selector(rest.FilterSelector.construct(filter=points))
+        elif isinstance(points, grpc.Filter):
+            points_selector = grpc.PointsSelector(
+                filter=points
+            )
+        else:
+            raise ValueError(f"Unsupported points selector type: {type(points)}")
+        return points_selector
+
+    @classmethod
+    def _try_argument_to_rest_selector(
+            cls,
+            points: types.PointsSelector
+    ) -> 'rest.PointsSelector':
+        if isinstance(points, list):
+            _points = [
+                GrpcToRest.convert_point_id(idx) if isinstance(idx, grpc.PointId) else idx
+                for idx in points
+            ]
+            points_selector = rest.PointIdsList.construct(points=_points)
+        elif isinstance(points, grpc.PointsSelector):
+            points_selector = GrpcToRest.convert_points_selector(points)
+        elif isinstance(points, (rest.PointIdsList, rest.FilterSelector)):
+            points_selector = points
+        elif isinstance(points, rest.Filter):
+            points_selector = rest.FilterSelector.construct(filter=points)
+        elif isinstance(points, grpc.Filter):
+            points_selector = rest.FilterSelector.construct(filter=GrpcToRest.convert_filter(points))
+        else:
+            raise ValueError(f"Unsupported points selector type: {type(points)}")
+        return points_selector
+
+    @classmethod
+    def _points_selector_to_points_list(cls, points_selector: grpc.PointsSelector) -> List[grpc.PointId]:
+        name = points_selector.WhichOneof("points_selector_one_of")
+        val = getattr(points_selector, name)
+
+        if name == "points":
+            return list(val.ids)
+        return []
+
+    @classmethod
+    def _try_argument_to_rest_points_and_filter(
+            cls,
+            points: types.PointsSelector
+    ) -> 'Tuple[Optional[List[rest.ExtendedPointId]], Optional[rest.Filter]]':
+        _points = None
+        _filter = None
+        if isinstance(points, list):
+            _points = [
+                GrpcToRest.convert_point_id(idx) if isinstance(idx, grpc.PointId) else idx
+                for idx in points
+            ]
+        elif isinstance(points, grpc.PointsSelector):
+            selector = GrpcToRest.convert_points_selector(points)
+            if isinstance(selector, rest.PointIdsList):
+                _points = selector.points
+            elif isinstance(selector, rest.FilterSelector):
+                _filter = selector.filter
+        elif isinstance(points, rest.PointIdsList):
+            _points = points.points
+        elif isinstance(points, rest.FilterSelector):
+            _filter = points.filter
+        elif isinstance(points, rest.Filter):
+            _filter = points
+        elif isinstance(points, grpc.Filter):
+            _filter = GrpcToRest.convert_filter(points)
+        else:
+            raise ValueError(f"Unsupported points selector type: {type(points)}")
+
+        return _points, _filter
+
     def delete(
             self,
             collection_name: str,
@@ -827,25 +945,26 @@ class QdrantClient:
                 - If `true`, result will be returned only when all changes are applied
                 - If `false`, result will be returned immediately after the confirmation of receiving.
             points_selector: Selects points based on list of IDs or filter
+                 Example:
+                    - `points=[1, 2, 3, "cd3b53f0-11a7-449f-bc50-d06310e7ed90"]`
+                    - `points=Filter(must=[FieldCondition(key='rand_number', range=Range(gte=0.7))])`
 
         Returns:
             Operation result
         """
         if self._prefer_grpc:
-            if isinstance(points_selector, (rest.PointIdsList, rest.FilterSelector)):
-                points_selector = RestToGrpc.convert_points_selector(points_selector)
+            points_selector = self._try_argument_to_grpc_selector(points_selector)
 
             return GrpcToRest.convert_update_result(
                 self._grpc_points_client.Delete(grpc.DeletePoints(
                     collection_name=collection_name,
                     wait=wait,
                     points=points_selector
-                )).result)
+                ), timeout=self._timeout).result)
         else:
-            if isinstance(points_selector, grpc.PointsSelector):
-                points_selector = GrpcToRest.convert_points_selector(points_selector)
+            points_selector = self._try_argument_to_rest_selector(points_selector)
 
-            self.openapi_client.points_api.delete_points(
+            return self.openapi_client.points_api.delete_points(
                 collection_name=collection_name,
                 wait=wait,
                 points_selector=points_selector
@@ -855,7 +974,7 @@ class QdrantClient:
             self,
             collection_name: str,
             payload: types.Payload,
-            points: List[types.PointId],
+            points: types.PointsSelector,
             wait: bool = True,
     ) -> types.UpdateResult:
         """Modifies payload of the specified points
@@ -882,35 +1001,100 @@ class QdrantClient:
                 - If `true`, result will be returned only when all changes are applied
                 - If `false`, result will be returned immediately after the confirmation of receiving.
             payload: Key-value pairs of payload to assign
-            points: List of affected points. Example: `points=[1, 2, 3, "cd3b53f0-11a7-449f-bc50-d06310e7ed90"]`
+            points: List of affected points, filter or points selector.
+             Example:
+                - `points=[1, 2, 3, "cd3b53f0-11a7-449f-bc50-d06310e7ed90"]`
+                - `points=Filter(must=[FieldCondition(key='rand_number', range=Range(gte=0.7))])`
 
         Returns:
             Operation result
         """
         if self._prefer_grpc:
-            points = [
-                RestToGrpc.convert_extended_point_id(idx) if isinstance(idx, (int, str)) else idx
-                for idx in points
-            ]
+            points_selector = self._try_argument_to_grpc_selector(points)
+
             return GrpcToRest.convert_update_result(
                 self._grpc_points_client.SetPayload(grpc.SetPayloadPoints(
                     collection_name=collection_name,
                     wait=wait,
                     payload=RestToGrpc.convert_payload(payload),
-                    points=points
-                )).result)
+                    points=self._points_selector_to_points_list(points_selector),  # deprecated
+                    points_selector=points_selector
+                ), timeout=self._timeout).result)
         else:
-            points = [
-                GrpcToRest.convert_point_id(idx) if isinstance(idx, grpc.PointId) else idx
-                for idx in points
-            ]
+            _points, _filter = self._try_argument_to_rest_points_and_filter(points)
 
             return self.openapi_client.points_api.set_payload(
                 collection_name=collection_name,
                 wait=wait,
                 set_payload=rest.SetPayload(
                     payload=payload,
-                    points=points
+                    points=_points,
+                    filter=_filter,
+                )
+            )
+
+    def overwrite_payload(
+            self,
+            collection_name: str,
+            payload: types.Payload,
+            points: types.PointsSelector,
+            wait: bool = True,
+    ) -> types.UpdateResult:
+        """Overwrites payload of the specified points
+        After this operation is applied, only the specified payload will be present in the point.
+        The existing payload, even if the key is not specified in the payload, will be deleted.
+
+        Examples:
+
+        `Set payload`::
+
+            # Overwrite payload value with key `"key"` to points 1, 2, 3.
+            # If any other valid payload value exists - it will be deleted
+            qdrant_client.overwrite_payload(
+                collection_name="test_collection",
+                wait=True,
+                payload={
+                    "key": "value"
+                },
+                points=[1,2,3]
+            )
+
+        Args:
+            collection_name: Name of the collection
+            wait: Await for the results to be processed.
+
+                - If `true`, result will be returned only when all changes are applied
+                - If `false`, result will be returned immediately after the confirmation of receiving.
+            payload: Key-value pairs of payload to assign
+            points: List of affected points, filter or points selector.
+             Example:
+                - `points=[1, 2, 3, "cd3b53f0-11a7-449f-bc50-d06310e7ed90"]`
+                - `points=Filter(must=[FieldCondition(key='rand_number', range=Range(gte=0.7))])`
+
+        Returns:
+            Operation result
+        """
+        if self._prefer_grpc:
+            points_selector = self._try_argument_to_grpc_selector(points)
+
+            return GrpcToRest.convert_update_result(
+                self._grpc_points_client.OverwritePayload(grpc.SetPayloadPoints(
+                    collection_name=collection_name,
+                    wait=wait,
+                    payload=RestToGrpc.convert_payload(payload),
+                    points=self._points_selector_to_points_list(points_selector),  # deprecated
+                    points_selector=points_selector
+                ), timeout=self._timeout).result)
+        else:
+            _points, _filter = self._try_argument_to_rest_points_and_filter(points)
+
+            return self.openapi_client.points_api.overwrite_payload(
+                collection_name=collection_name,
+                wait=wait,
+                set_payload=rest.SetPayload(
+                    payload=payload,
+                    points=_points,
+                    filter=_filter,
                 )
             )
 
@@ -918,7 +1102,7 @@ class QdrantClient:
             self,
             collection_name: str,
             keys: List[str],
-            points: List[types.PointId],
+            points: types.PointsSelector,
             wait: bool = True,
     ):
         """Remove values from point's payload
@@ -930,34 +1114,33 @@ class QdrantClient:
                 - If `true`, result will be returned only when all changes are applied
                 - If `false`, result will be returned immediately after the confirmation of receiving.
             keys: List of payload keys to remove
-            points: List of affected points. Example: `points=[1, 2, 3, "cd3b53f0-11a7-449f-bc50-d06310e7ed90"]`
+            points: List of affected points, filter or points selector.
+                Example:
+                   - `points=[1, 2, 3, "cd3b53f0-11a7-449f-bc50-d06310e7ed90"]`
+                   - `points=Filter(must=[FieldCondition(key='rand_number', range=Range(gte=0.7))])`
 
         Returns:
             Operation result
         """
         if self._prefer_grpc:
-            points = [
-                RestToGrpc.convert_extended_point_id(idx) if isinstance(idx, (int, str)) else idx
-                for idx in points
-            ]
+            points_selector = self._try_argument_to_grpc_selector(points)
             return GrpcToRest.convert_update_result(
                 self._grpc_points_client.DeletePayload(grpc.DeletePayloadPoints(
                     collection_name=collection_name,
                     wait=wait,
                     keys=keys,
-                    points=points
-                )).result)
+                    points=self._points_selector_to_points_list(points_selector),  # deprecated
+                    points_selector=points_selector
+                ), timeout=self._timeout).result)
         else:
-            points = [
-                GrpcToRest.convert_point_id(idx) if isinstance(idx, grpc.PointId) else idx
-                for idx in points
-            ]
+            _points, _filter = self._try_argument_to_rest_points_and_filter(points)
             return self.openapi_client.points_api.delete_payload(
                 collection_name=collection_name,
                 wait=wait,
                 delete_payload=rest.DeletePayload(
                     keys=keys,
-                    points=points
+                    points=_points,
+                    filter=_filter,
                 )
             )
 
@@ -975,24 +1158,25 @@ class QdrantClient:
 
                 - If `true`, result will be returned only when all changes are applied
                 - If `false`, result will be returned immediately after the confirmation of receiving.
-            points_selector: Selects points based on list of IDs or filter
+            points_selector: List of affected points, filter or points selector.
+                Example:
+                   - `points=[1, 2, 3, "cd3b53f0-11a7-449f-bc50-d06310e7ed90"]`
+                   - `points=Filter(must=[FieldCondition(key='rand_number', range=Range(gte=0.7))])`
 
         Returns:
             Operation result
         """
         if self._prefer_grpc:
-            if isinstance(points_selector, (rest.PointIdsList, rest.FilterSelector)):
-                points_selector = RestToGrpc.convert_points_selector(points_selector)
+            points_selector = self._try_argument_to_grpc_selector(points_selector)
 
             return GrpcToRest.convert_update_result(
                 self._grpc_points_client.ClearPayload(grpc.ClearPayloadPoints(
                     collection_name=collection_name,
                     wait=wait,
                     points=points_selector
-                )).result)
+                ), timeout=self._timeout).result)
         else:
-            if isinstance(points_selector, grpc.PointsSelector):
-                points_selector = GrpcToRest.convert_points_selector(points_selector)
+            points_selector = self._try_argument_to_rest_selector(points_selector)
 
             return self.openapi_client.points_api.clear_payload(
                 collection_name=collection_name,
@@ -1038,7 +1222,8 @@ class QdrantClient:
             List of the collections
         """
         if self._prefer_grpc:
-            response = self._grpc_collections_client.List(grpc.ListCollectionsRequest()).collections
+            response = self._grpc_collections_client.List(grpc.ListCollectionsRequest(),
+                                                          timeout=self._timeout).collections
             return types.CollectionsResponse(
                 collections=[GrpcToRest.convert_collection_description(description) for description in response]
             )
@@ -1058,7 +1243,7 @@ class QdrantClient:
             return GrpcToRest.convert_collection_info(
                 self._grpc_collections_client.Get(grpc.GetCollectionInfoRequest(
                     collection_name=collection_name
-                )).result)
+                ), timeout=self._timeout).result)
         return self.http.collections_api.get_collection(collection_name=collection_name).result
 
     def update_collection(
@@ -1377,6 +1562,29 @@ class QdrantClient:
         """
         return self.openapi_client.snapshots_api.create_full_snapshot().result
 
+    def recover_snapshot(self, collection_name: str, location: str,
+                         priority: Optional[types.SnapshotPriority] = None) -> bool:
+        """Recover collection from snapshot.
+
+        Args:
+            collection_name: Name of the collection
+            location:
+                URL of the snapshot.
+                Example:
+                    - URL `http://localhost:8080/collections/my_collection/snapshots/my_snapshot`
+                    - Local path `file:///qdrant/snapshots/test_collection-2022-08-04-10-49-10.snapshot`
+            priority:
+                Defines source of truth for snapshot recovery
+                    - `snapshot` means - prefer snapshot data over the current state
+                    - `replica` means - prefer existing data over the snapshot
+                Default: `replica`
+
+        """
+        return self.openapi_client.snapshots_api.recover_from_snapshot(
+            collection_name=collection_name,
+            recover_snapshot=rest.SnapshotRecover(location=location, priority=priority)
+        ).result
+
     def lock_storage(self, reason: str):
         """Lock storage for writing.
         """
